@@ -1,7 +1,6 @@
 from crownstone_core.protocol.BlePackets import ControlStateSetPacket, ControlPacket
 from crownstone_core.protocol.BluenetTypes import StateType, ControlType
 
-from crownstone_uart.core.containerClasses.CrownstoneUartState import CrownstoneUartState
 from crownstone_uart.core.UartEventBus import UartEventBus
 from crownstone_uart.core.uart.uartPackets.UartMessagePacket import UartMessagePacket
 from crownstone_uart.core.uart.UartTypes import UartTxType, UartMessageType
@@ -11,9 +10,6 @@ from crownstone_uart.topics.SystemTopics import SystemTopics
 
 class UsbDevHandler:
     
-    def __init__(self, libState: CrownstoneUartState):
-        self.libState = libState
-    
     def setAdvertising(self, enabled):
         """
             Enable/ disable the advertising
@@ -149,7 +145,7 @@ class UsbDevHandler:
             :param mode: : 0=none 1=RX only, 2=TX only, 3=TX and RX
             :return:
         """
-        if ((mode < 0) or (mode > 3)):
+        if (mode < 0) or (mode > 3):
             return
         controlPacket = ControlStateSetPacket(StateType.UART_ENABLED).loadUInt8(mode).getPacket()
         self._send(UartTxType.CONTROL, controlPacket)
