@@ -6,7 +6,6 @@ import time
 from crownstone_core.protocol.BlePackets import ControlPacket
 from crownstone_core.protocol.BluenetTypes import ControlType
 
-from crownstone_uart.core.containerClasses.CrownstoneUartState import CrownstoneUartState
 from crownstone_uart.core.dataFlowManagers.Collector import Collector
 from crownstone_uart.core.uart.uartPackets.UartCommandHelloPacket import UartCommandHelloPacket
 from crownstone_uart.core.uart.uartPackets.UartCrownstoneHelloPacket import UartCrownstoneHelloPacket
@@ -26,10 +25,10 @@ _LOGGER = logging.getLogger(__name__)
 
 class UartManager(threading.Thread):
 
-    def __init__(self, libState: CrownstoneUartState):
-        self.libState = libState
+    def __init__(self):
         self.port = None
         self.baudRate = 230400
+        self.writeChunkMaxSize = 0
         self.running = True
         self.loop = None
         self._availablePorts = list(list_ports.comports())
@@ -43,9 +42,10 @@ class UartManager(threading.Thread):
     def __del__(self):
         self.stop()
 
-    def config(self, port, baudRate = 230400):
+    def config(self, port, baudRate = 230400, writeChunkMaxSize=0):
         self.port     = port
         self.baudRate = baudRate
+        self.writeChunkMaxSize = writeChunkMaxSize
 
     def run(self):
         self.loop = asyncio.new_event_loop()
@@ -132,7 +132,7 @@ class UartManager(threading.Thread):
 
     def setupConnection(self, port, handshake=True):
         _LOGGER.debug(F"Setting up connection...{port} {self.baudRate} {handshake}")
-        self._uartBridge = UartBridge(port, self.baudRate)
+        self._uartBridge = UartBridge(port, self.baudRate, self.writeChunkMaxSize)
         self._uartBridge.start()
 
         # wait for the bridge to initialize
