@@ -1,22 +1,23 @@
-import sys
-import logging
 import datetime
+import logging
 
+from crownstone_core.Exceptions import CrownstoneError
 from crownstone_core.packets.ResultPacket import ResultPacket
 from crownstone_core.packets.ServiceData import ServiceData
+from crownstone_core.packets.serviceDataParsers.parsers import parseOpcode7
 from crownstone_core.util.Conversion import Conversion
 
 from crownstone_uart.core.UartEventBus import UartEventBus
-from crownstone_uart.core.uart.UartLogParser import UartLogParser
 from crownstone_uart.core.uart.UartTypes import UartRxType, UartMessageType
-from crownstone_uart.core.uart.uartPackets.UartMessagePacket import UartMessagePacket
-from crownstone_uart.core.uart.uartPackets.UartWrapperPacket import UartWrapperPacket, PROTOCOL_MAJOR
 from crownstone_uart.core.uart.uartPackets.AdcConfigPacket import AdcConfigPacket
 from crownstone_uart.core.uart.uartPackets.CurrentSamplesPacket import CurrentSamplesPacket
 from crownstone_uart.core.uart.uartPackets.PowerCalculationPacket import PowerCalculationPacket
-from crownstone_uart.core.uart.uartPackets.StoneStatePacket import StoneStatePacket
-from crownstone_uart.core.uart.uartPackets.VoltageSamplesPacket import VoltageSamplesPacket
 from crownstone_uart.core.uart.uartPackets.UartCrownstoneHelloPacket import UartCrownstoneHelloPacket
+from crownstone_uart.core.uart.uartPackets.UartLogArrayPacket import UartLogArrayPacket
+from crownstone_uart.core.uart.uartPackets.UartLogPacket import UartLogPacket
+from crownstone_uart.core.uart.uartPackets.UartMessagePacket import UartMessagePacket
+from crownstone_uart.core.uart.uartPackets.UartWrapperPacket import UartWrapperPacket, PROTOCOL_MAJOR
+from crownstone_uart.core.uart.uartPackets.VoltageSamplesPacket import VoltageSamplesPacket
 from crownstone_uart.topics.DevTopics import DevTopics
 from crownstone_uart.topics.SystemTopics import SystemTopics
 from crownstone_uart.topics.UartTopics import UartTopics
@@ -33,7 +34,6 @@ class UartParser:
     def __init__(self):
         self.uartPackageSubscription = UartEventBus.subscribe(SystemTopics.uartNewPackage, self.parse)
         self.uartMessageSubscription = UartEventBus.subscribe(SystemTopics.uartNewMessage, self.handleUartMessage)
-        self.uartLogParser = UartLogParser()
         self.timestampFormat = "%Y-%m-%d %H:%M:%S.%f"
 
     def stop(self):
@@ -67,6 +67,15 @@ class UartParser:
             return
 
     def handleUartMessage(self, messagePacket: UartMessagePacket):
+        try:
+            self._handleUartMessage(messagePacket)
+        except CrownstoneError as e:
+            # TODO: don't we catch too many errors this way
+            #  For example errors from code executed by emitted events.
+            #  We only want to catch parse errors, but we're too lazy to put a try catch around every parse call.
+            _LOGGER.warning(f"Parse error: {e}")
+
+    def _handleUartMessage(self, messagePacket: UartMessagePacket):
         """
         Callback for SystemTopics.uartNewMessage. This transforms a select number of message types
         into further specialized messages and posts those on UartEventBus.
@@ -76,6 +85,7 @@ class UartParser:
         opCode = messagePacket.opCode
         parsedData = None
         # print("UART - opCode:", opCode, "payload:", dataPacket.payload)
+
         if opCode == UartRxType.HELLO:
             helloPacket = UartCrownstoneHelloPacket(messagePacket.payload)
             UartEventBus.emit(UartTopics.hello, helloPacket)
@@ -141,8 +151,8 @@ class UartParser:
         elif opCode == UartRxType.OWN_SERVICE_DATA:
             # service data type + device type + data type + service data (15b)
             serviceData = ServiceData(messagePacket.payload)
-            if serviceData.validData:
-                UartEventBus.emit(DevTopics.newServiceData, serviceData.getDictionary())
+            serviceData.parse()
+            UartEventBus.emit(DevTopics.newServiceData, serviceData.payload)
 
         elif opCode == UartRxType.PRESENCE_CHANGE:
             pass
@@ -159,11 +169,9 @@ class UartParser:
 
         elif opCode == UartRxType.MESH_SERVICE_DATA:
             # data type + service data (15b)
-            serviceData = ServiceData(messagePacket.payload, unencrypted=True)
-            statePacket = StoneStatePacket(serviceData)
-            statePacket.broadcastState()
-            # if serviceData.validData:
-            #     UartEventBus.emit(DevTopics.newServiceData, serviceData.getDictionary())
+            result = parseOpcode7(messagePacket.payload)
+            if hasattr(result,"crownstoneId"):
+                UartEventBus.emit(SystemTopics.stateUpdate, (result.crownstoneId, result))
 
         elif opCode == UartRxType.EXTERNAL_STATE_PART_0:
             pass
@@ -187,11 +195,13 @@ class UartParser:
 
         elif opCode == UartRxType.LOG:
             _LOGGER.debug(f"Received binary log: {messagePacket.payload}")
-            self.uartLogParser.parse(messagePacket.payload)
+            packet = UartLogPacket(messagePacket.payload)
+            UartEventBus.emit(UartTopics.log, packet)
 
         elif opCode == UartRxType.LOG_ARRAY:
             _LOGGER.debug(f"Received binary log array: {messagePacket.payload}")
-            self.uartLogParser.parseArray(messagePacket.payload)
+            packet = UartLogArrayPacket(messagePacket.payload)
+            UartEventBus.emit(UartTopics.logArray, packet)
 
 
         ####################
@@ -248,8 +258,6 @@ class UartParser:
         #     else:
         #         print("invalid address:", messagePacket.payload)
 
-
-
         elif opCode == UartRxType.ADC_CONFIG:
             # type is PowerCalculationsPacket
             parsedData = AdcConfigPacket(messagePacket.payload)
@@ -258,35 +266,31 @@ class UartParser:
         elif opCode == UartRxType.ADC_RESTART:
             UartEventBus.emit(DevTopics.adcRestarted, None)
 
-
-
         elif opCode == UartRxType.POWER_LOG_CURRENT:
             # type is CurrentSamples
             parsedData = CurrentSamplesPacket(messagePacket.payload)
             UartEventBus.emit(DevTopics.newCurrentData, parsedData.getDict())
-            
+
         elif opCode == UartRxType.POWER_LOG_VOLTAGE:
             # type is VoltageSamplesPacket
             parsedData = VoltageSamplesPacket(messagePacket.payload)
             UartEventBus.emit(DevTopics.newVoltageData, parsedData.getDict())
-            
+
         elif opCode == UartRxType.POWER_LOG_FILTERED_CURRENT:
             # type is CurrentSamples
             parsedData = CurrentSamplesPacket(messagePacket.payload)
             UartEventBus.emit(DevTopics.newFilteredCurrentData, parsedData.getDict())
-            
+
         elif opCode == UartRxType.POWER_LOG_FILTERED_VOLTAGE:
             # type is VoltageSamplesPacket
             parsedData = VoltageSamplesPacket(messagePacket.payload)
             UartEventBus.emit(DevTopics.newFilteredVoltageData, parsedData.getDict())
-            
+
         elif opCode == UartRxType.POWER_LOG_POWER:
             # type is PowerCalculationsPacket
             parsedData = PowerCalculationPacket(messagePacket.payload)
             UartEventBus.emit(DevTopics.newCalculatedPowerData, parsedData.getDict())
 
-
-
         elif opCode == UartRxType.ASCII_LOG:
             timestamp = datetime.datetime.now()
             stringResult = ""
@@ -301,11 +305,8 @@ class UartParser:
             # no need to process this, that's in the test suite.
             pass
 
-
-
         else:
             _LOGGER.warning(f"Unknown opCode: {opCode}")
 
-        
         parsedData = None
         
